@@ -30,6 +30,7 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
+#include <pciaccess.h>
 
 #include "drmtest.h"
 #include "i915/gem.h"
@@ -492,6 +493,7 @@ void igt_stop_hang_helper(void)
 
 /**
  * igt_open_forcewake_handle:
+ * @fd: drm fd - i915 or xe
  *
  * This functions opens the debugfs forcewake file and so prevents the GT from
  * suspending. The reference is automatically dropped when the is closed.
@@ -501,9 +503,58 @@ void igt_stop_hang_helper(void)
  */
 int igt_open_forcewake_handle(int fd)
 {
+	const char *fn;
+
 	if (getenv("IGT_NO_FORCEWAKE"))
 		return -1;
-	return igt_debugfs_open(fd, "i915_forcewake_user", O_WRONLY);
+
+	if (is_xe_device(fd))
+		fn = "forcewake_all";
+	else if (is_i915_device(fd))
+		fn = "i915_forcewake_user";
+	else
+		return -1;
+
+	return igt_debugfs_open(fd, fn, O_RDONLY);
+}
+
+int igt_open_forcewake_handle_for_pcidev(const struct pci_device *pci_dev)
+{
+	static const char *FORCEWAKE_FILES[] = {
+		"forcewake_all", "i915_forcewake_user",
+		NULL
+	};
+	const char *debugfs_root = igt_debugfs_mount(), **fn;
+	char path[PATH_MAX];
+	int dirlen, ret;
+
+	if (!debugfs_root)
+		return -ENOENT;
+
+	ret = snprintf(path, sizeof(path), "%s/dri/%04x:%02x:%02x.%x",
+		       debugfs_root,
+		       pci_dev->domain, pci_dev->bus, pci_dev->dev,
+		       pci_dev->func);
+	if (ret < 0 || ret >= sizeof(path))
+		return -EINVAL;
+
+	dirlen = ret;
+	for (fn = FORCEWAKE_FILES; *fn; fn++) {
+		ret = snprintf(path + dirlen, sizeof(path) - dirlen,
+			       "/%s", *fn);
+		if (ret < 0 || ret >= sizeof(path) - dirlen)
+			return -EINVAL;
+
+		ret = open(path, O_RDONLY);
+		if (ret >= 0)
+			return ret;
+
+		if (errno != ENOENT)
+			return -errno;
+	}
+
+	return -ENOENT;
+
 }
 
 #if defined(__x86_64__) || defined(__i386__)
@@ -604,21 +655,35 @@ unsigned intel_detect_and_clear_missed_interrupts(int fd)
 	return missed;
 }
 
+static bool gem_store_dword_needs_physical(const struct intel_device_info *info)
+{
+	switch (info->graphics_ver) {
+	case 2:
+		return true;
+	case 3:
+		return info->is_grantsdale || info->is_alviso;
+	default:
+		return false;
+	}
+}
+
+/**
+ * gem_class_can_store_dword:
+ * @fd: open i915 drm file descriptor
+ * @class: engine class
+ *
+ * Returns:
+ * True if MI_STORE_DWORD is actually usable.
+ */
 bool gem_class_can_store_dword(int fd, int class)
 {
 	uint16_t devid = intel_get_drm_devid(fd);
 	const struct intel_device_info *info = intel_get_device_info(devid);
 	const int ver = info->graphics_ver;
 
-	if (ver == 0) /* unknown, assume it just works */
-		return true;
-
-	if (ver <= 2) /* requires physical addresses */
+	if (gem_store_dword_needs_physical(info))
 		return false;
 
-	if (ver == 3 && (info->is_grantsdale || info->is_alviso))
-		return false; /* only supports physical addresses */
-
 	if (ver == 6 && class == I915_ENGINE_CLASS_VIDEO)
 		return false; /* broken, unbelievably broken */
 
@@ -628,12 +693,42 @@ bool gem_class_can_store_dword(int fd, int class)
 	return true;
 }
 
+/**
+ * gem_can_store_dword:
+ * @fd: open i915 drm file descriptor
+ * @engine: engine
+ *
+ * Returns:
+ * True if MI_STORE_DWORD is actually usable.
+ */
 bool gem_can_store_dword(int fd, unsigned int engine)
 {
 	return gem_class_can_store_dword(fd,
 				gem_execbuf_flags_to_engine_class(engine));
 }
 
+/**
+ * gem_store_dword_needs_secure:
+ * @fd: open i915 drm file descriptor
+ *
+ * Returns:
+ * True if the MI_STORE_DWORD needs to be executed from a secure batch.
+ */
+bool gem_store_dword_needs_secure(int fd)
+{
+	const struct intel_device_info *info =
+		intel_get_device_info(intel_get_drm_devid(fd));
+
+	switch (info->graphics_ver) {
+	case 4:
+		return info->is_eaglelake || info->is_cantiga;
+	case 5:
+		return true;
+	default:
+		return false;
+	}
+}
+
 const struct intel_execution_engine2 intel_execution_engines2[] = {
 	{ "rcs0", I915_ENGINE_CLASS_RENDER, 0, I915_EXEC_RENDER },
 	{ "bcs0", I915_ENGINE_CLASS_COPY, 0, I915_EXEC_BLT },
