@@ -39,10 +39,10 @@
 #include <fcntl.h>
 #include <inttypes.h>
 #include <errno.h>
+#include <poll.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <sys/time.h>
-#include <sys/poll.h>
 #include <pthread.h>
 #include "drm.h"
 
@@ -50,6 +50,23 @@
 
 IGT_TEST_DESCRIPTION("Call read(drm) and see if it behaves.");
 
+/**
+ * TEST: drm read
+ * Description: boundary testing of read(drm_fd)
+ * Category: Core
+ * Mega feature: General Core features
+ * Sub-category: uapi
+ * Functionality: drm_mm
+ *
+ * SUBTEST: invalid-buffer
+ * SUBTEST: fault-buffer
+ * SUBTEST: empty-block
+ * SUBTEST: empty-nonblock
+ * SUBTEST: short-buffer-block
+ * SUBTEST: short-buffer-nonblock
+ * SUBTEST: short-buffer-wakeup
+ */
+
 static void sighandler(int sig, siginfo_t * info, void *context)
 {
 }
