@@ -51,13 +51,13 @@
 #include "ioctl_wrappers.h"
 /**
  * TEST: dumb buffer
- * Category: Desktop client
  * Description: This is a test for the generic dumb buffer interface.
+ * Category: Core
+ * Mega feature: General Core features
+ * Sub-category: uapi
+ * Functionality: ioctl
  * Feature: prime
- * Functionality: IOCTL check for buffer management
- * Run type: FULL
- * Sub-category: Compositor
- * Test category: GEM_Legacy
+ * Test category: Compositor
  *
  * SUBTEST: create-clear
  *
@@ -143,7 +143,7 @@ static void invalid_dimensions_test(int fd)
 	memset(&create, 0, sizeof(create));
 	create.width = 4032;
 	create.height = 2016;
-	create.bpp = 24;
+	create.bpp = 0;
 	igt_assert_eq(__dumb_create(fd, &create), -EINVAL);
 
 	create.bpp = 32;
@@ -242,7 +242,7 @@ static uint64_t get_npages(_Atomic(uint64_t) *global, uint64_t npages)
 }
 
 struct thread_clear {
-	_Atomic(uint64_t) max;
+	_Atomic(uint64_t) max __attribute__((aligned(8)));
 	uint64_t page_size;
 	int timeout;
 	int fd;
