@@ -35,7 +35,11 @@
 #include <errno.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
+#ifdef ANDROID
+#include "android/glib.h"
+#else
 #include <glib.h>
+#endif
 #include <zlib.h>
 #include "intel_bufops.h"
 #include "i915/gem_vm.h"
@@ -944,7 +948,8 @@ static int dump_base64(const char *name, struct intel_buf *buf)
 
 		igt_info("--- %s ---\n", name);
 		pos = str = g_base64_encode(destbuf, outsize);
-		outsize = strlen(str);
+		outsize = str ? strlen(str) : 0;
+
 		while (pos) {
 			char line[LINELEN + 1];
 			int to_copy = min(LINELEN, outsize);
@@ -1339,7 +1344,7 @@ static int render(struct buf_ops *bops, uint32_t tiling, bool do_reloc,
 			       0, 0, width, height,
 			       0, 0, width, height, 0);
 
-	render_copy = igt_get_render_copyfunc(devid);
+	render_copy = igt_get_render_copyfunc(i915);
 	igt_assert(render_copy);
 
 	render_copy(ibb,
@@ -1439,7 +1444,7 @@ static void render_ccs(struct buf_ops *bops)
 	scratch_buf_init(bops, &final, width, height, I915_TILING_NONE,
 			 I915_COMPRESSION_NONE);
 
-	render_copy = igt_get_render_copyfunc(devid);
+	render_copy = igt_get_render_copyfunc(i915);
 	igt_assert(render_copy);
 
 	intel_buf_draw_pattern(bops, &src,
