@@ -38,91 +38,62 @@
 /**
  * TEST: gem ctx create
  * Description: Test the context create ioctls
+ * Category: Core
+ * Mega feature: General Core features
+ * Sub-category: CMD submission
+ * Functionality: context
+ * Feature: context
+ * Test category: GEM_Legacy
  *
  * SUBTEST: active
- * Description:
- *   For each engine calculate the average performance of context creation execution and
- *   exercise context reclaim
- * Feature: context
- * Run type: FULL
+ * Description: For each engine calculate the average performance of context
+ *		creation execution and exercise context reclaim
  *
  * SUBTEST: active-all
- * Description: Calculate the average performance of context creation and it's execution using all engines
- * Feature: context
- * Run type: FULL
+ * Description: Calculate the average performance of context creation and it's
+ *		execution using all engines
  *
  * SUBTEST: basic
- * Category: Infrastructure
  * Description: Test random context creation
- * Feature: context
- * Functionality: context management
- * Run type: BAT
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: basic-files
- * Category: Infrastructure
  * Description: Exercise implicit per-fd context creation
- * Feature: context
- * Functionality: context management
- * Run type: BAT
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: ext-param
  * Description: Verify valid and invalid context extensions
- * Feature: context
- * Run type: FULL
  *
  * SUBTEST: files
  * Description: Exercise implicit per-fd context creation on 1 CPU for long duration
- * Feature: context
- * Run type: FULL
  *
  * SUBTEST: forked-active
- * Description:
- *   For each engine calculate the average performance of context creation and execution on
- *   multiple parallel processes
- * Feature: context
- * Run type: FULL
+ * Description: For each engine calculate the average performance of context
+ *		creation and execution on multiple parallel processes
  *
  * SUBTEST: forked-active-all
- * Description:
- *   Calculate the average performance of context creation and it's execution using all engines
- *   on multiple parallel processes
- * Feature: context
- * Run type: FULL
+ * Description: Calculate the average performance of context creation and it's
+ *		execution using all engines on multiple parallel processes
  *
  * SUBTEST: forked-files
- * Description: Exercise implicit per-fd context creation on all CPUs for long duration
- * Feature: context
- * Run type: FULL
+ * Description: Exercise implicit per-fd context creation on all CPUs for long
+ *		duration
  *
  * SUBTEST: hog
- * Description:
- *   For each engine calculate the average performance of context creation and execution while
- *   all other engines are hogging the resources
- * Feature: context
- * Run type: FULL
+ * Description: For each engine calculate the average performance of context
+ *		creation and execution while all other engines are hogging the
+ *		resources
  *
  * SUBTEST: iris-pipeline
  * Description: Set, validate and execute particular context params
- * Feature: context
- * Run type: FULL
  *
  * SUBTEST: maximum-mem
- * Description:
- *   Create contexts upto available RAM size, calculate the average performance of their
- *   execution on multiple parallel processes
- * Feature: context
- * Run type: FULL
+ * Description: Create contexts up to available RAM size, calculate the average
+ *		performance of their execution on multiple parallel processes
  *
  * SUBTEST: maximum-swap
- * Description:
- *   Create contexts upto available RAM+SWAP size, calculate the average performance of their
- *   execution on multiple parallel processes
- * Feature: context
- * Run type: FULL
+ * Description: Create contexts up to available RAM+SWAP size, calculate the
+ *		average performance of their execution on multiple parallel
+ *		processes
+ *
  */
 
 IGT_TEST_DESCRIPTION("Test the context create ioctls");
@@ -324,20 +295,16 @@ static void active(int fd, const intel_ctx_cfg_t *cfg,
 
 static void xchg_u32(void *array, unsigned i, unsigned j)
 {
-	uint32_t *a = array, tmp;
+	uint32_t *a = array;
 
-	tmp = a[i];
-	a[i] = a[j];
-	a[j] = tmp;
+	igt_swap(a[i], a[j]);
 }
 
 static void xchg_ptr(void *array, unsigned i, unsigned j)
 {
-	void **a = array, *tmp;
+	void **a = array;
 
-	tmp = a[i];
-	a[i] = a[j];
-	a[j] = tmp;
+	igt_swap(a[i], a[j]);
 }
 
 static unsigned __context_size(int fd)
