@@ -56,197 +56,78 @@
 /**
  * TEST: gem eio
  * Description: Test that specific ioctls report a wedged GPU (EIO).
- * Run type: FULL
+ * Mega feature: General Core features
+ * Category: Core
+ * Sub-category: uapi
+ * Functionality: reset
+ * Feature: reset
+ * Test category: GEM_Legacy
  *
  * SUBTEST: banned
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: context-create
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: create
- * Category: Infrastructure
  * Description: Validate i915_gem_create_ioctl, while gpu is wedged for fb scanout.
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: create-ext
- * Category: Infrastructure
- * Description:
- *   Validate i915_gem_create_ext_ioctl and checks if returns clear backing store while gpu is
- *   wedged for fb scanout.
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
+ * Description: Validate i915_gem_create_ext_ioctl and checks if returns clear
+ *		backing store while gpu is wedged for fb scanout.
  *
  * SUBTEST: execbuf
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: hibernate
  * Description: Test that specific ioctls report a wedged GPU (EIO) during suspend
- * Feature: hibernate, reset, suspend
- * Test category: suspend
  *
  * SUBTEST: in-flight-10ms
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: in-flight-1us
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: in-flight-contexts-10ms
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: in-flight-contexts-1us
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: in-flight-contexts-immediate
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: in-flight-external
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: in-flight-immediate
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: in-flight-internal-10ms
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: in-flight-internal-1us
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: in-flight-internal-immediate
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: in-flight-suspend
  * Description: Test that specific ioctls report a wedged GPU (EIO) during suspend
  * Feature: reset, suspend
- * Test category: suspend
  *
  * SUBTEST: kms
  * Feature: kms_gem_interop, reset
  *
  * SUBTEST: reset-stress
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: suspend
  * Description: Test that specific ioctls report a wedged GPU (EIO) during suspend
  * Feature: reset, suspend
- * Test category: suspend
  *
  * SUBTEST: throttle
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: unwedge-stress
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: wait-10ms
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: wait-1us
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: wait-immediate
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: wait-wedge-10ms
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: wait-wedge-1us
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
  *
  * SUBTEST: wait-wedge-immediate
- * Category: Infrastructure
- * Feature: reset
- * Functionality: reset
- * Sub-category: i915
- * Test category: GEM_Legacy
+ *
  */
 
 IGT_TEST_DESCRIPTION("Test that specific ioctls report a wedged GPU (EIO).");
@@ -746,7 +627,7 @@ static void test_inflight(int fd, unsigned int wait)
 		for (unsigned int n = 0; n < max; n++) {
 			gem_execbuf_wr(fd, &execbuf);
 			fence[n] = execbuf.rsvd2 >> 32;
-			igt_assert(fence[n] != -1);
+			igt_assert_neq(fence[n], -1);
 		}
 
 		igt_debugfs_dump(fd, "i915_engine_info");
@@ -806,7 +687,7 @@ static void test_inflight_suspend(int fd)
 	for (unsigned int n = 0; n < max; n++) {
 		gem_execbuf_wr(fd, &execbuf);
 		fence[n] = execbuf.rsvd2 >> 32;
-		igt_assert(fence[n] != -1);
+		igt_assert_neq(fence[n], -1);
 	}
 
 	igt_set_autoresume_delay(30);
@@ -893,7 +774,7 @@ static void test_inflight_contexts(int fd, unsigned int wait)
 			if (__gem_execbuf_wr(fd, &execbuf))
 				break; /* small shared ring */
 			fence[n] = execbuf.rsvd2 >> 32;
-			igt_assert(fence[n] != -1);
+			igt_assert_neq(fence[n], -1);
 			count++;
 		}
 
@@ -1004,7 +885,7 @@ static void test_inflight_internal(int fd, unsigned int wait)
 		gem_execbuf_wr(fd, &execbuf);
 
 		fences[nfence] = execbuf.rsvd2 >> 32;
-		igt_assert(fences[nfence] != -1);
+		igt_assert_neq(fences[nfence], -1);
 		nfence++;
 	}
 
@@ -1111,8 +992,16 @@ static void test_reset_stress(int fd, unsigned int flags)
 	const intel_ctx_t *ctx0 = context_create_safe(fd);
 	uint64_t ahnd = get_reloc_ahnd(fd, ctx0->id);
 
-	for_each_ring(e, fd)
+	for_each_ring(e, fd) {
+		struct intel_execution_engine2 engine;
+
+		engine = gem_eb_flags_to_engine(eb_ring(e));
+
+		if (gem_engine_can_block_ggtt_binder(fd, &engine))
+			continue;
+
 		reset_stress(fd, ahnd, ctx0, e->name, eb_ring(e), flags);
+	}
 
 	intel_ctx_destroy(fd, ctx0);
 	put_ahnd(ahnd);
