@@ -21,9 +21,10 @@
  * IN THE SOFTWARE.
  */
 
-#include <sys/poll.h>
-#include <zlib.h>
+#include <ctype.h>
+#include <poll.h>
 #include <sched.h>
+#include <zlib.h>
 
 #include "i915/gem.h"
 #include "i915/gem_create.h"
@@ -34,22 +35,22 @@
 /**
  * TEST: gem exec capture
  * Description: Check that we capture the user specified objects on a hang
- * Feature: cmd_submission
- * Run type: FULL
- *
- * SUBTEST: capture
- * Category: Server
+ * Category: Core
+ * Mega feature: General Core features
+ * Sub-category: Debugging
  * Functionality: offline debugging
- * Sub-category: debugger
+ * Feature: cmd_submission
  * Test category: GEM_Legacy
  *
+ * SUBTEST: capture
+ *
  * SUBTEST: capture-invisible
- * Description:
- *   Check that the kernel doesn't crash if the pages can't be copied from the CPU during error
- *   capture.
+ * Description: Check that the kernel doesn't crash if the pages can't be
+ *		copied from the CPU during error capture.
  *
  * SUBTEST: capture-recoverable
- * Description: Verify that the kernel rejects EXEC_OBJECT_CAPTURE with recoverable contexts.
+ * Description: Verify that the kernel rejects EXEC_OBJECT_CAPTURE with
+ *		recoverable contexts.
  *
  * SUBTEST: many-256M-incremental
  *
@@ -62,16 +63,9 @@
  * SUBTEST: many-4K-zero
  *
  * SUBTEST: pi
- * Category: Server
- * Functionality: offline debugging
- * Sub-category: debugger
- * Test category: GEM_Legacy
  *
  * SUBTEST: userptr
- * Category: Server
- * Functionality: offline debugging
- * Sub-category: debugger
- * Test category: GEM_Legacy
+ *
  */
 
 #define MAX_RESET_TIME	600
@@ -184,6 +178,19 @@ static int check_error_state(int dir, struct offset *obj_offsets, int obj_count,
 	igt_assert(errno != ENOMEM);
 	igt_debug("%.*s\n", error_dump_limit, error);
 
+	/*
+	 * global --- GuC Error Capture on rcs0 command stream:
+	 * Coverage:  partial-capture
+	 * Coverage:  full-capture
+	 */
+	for (str = error; (str = strstr(str, "Coverage: ")); ) {
+		str += 10;
+		while (isspace(*str))
+			str++;
+
+		igt_assert(strncmp(str, "full-capture", 12) == 0);
+	}
+
 	/* render ring --- user = 0x00000000 ffffd000 */
 	for (str = error; (str = strstr(str, "--- user = ")); ) {
 		uint32_t *data = NULL;
@@ -258,7 +265,7 @@ configure_hangs(int fd, const struct intel_execution_engine2 *e, int ctxt_id)
 	struct gem_engine_properties props;
 
 	/* Ensure fast hang detection */
-	props.engine = e;
+	props.engine = *e;
 	props.preempt_timeout = 250;
 	props.heartbeat_interval = 500;
 	gem_engine_properties_configure(fd, &props);
@@ -389,7 +396,7 @@ static void __capture1(int fd, int dir, uint64_t ahnd, const intel_ctx_t *ctx,
 	execbuf.buffers_ptr = (uintptr_t)obj;
 	execbuf.buffer_count = ARRAY_SIZE(obj);
 	execbuf.flags = e->flags;
-	if (gen > 3 && gen < 6)
+	if (gem_store_dword_needs_secure(fd))
 		execbuf.flags |= I915_EXEC_SECURE;
 	execbuf.flags |= I915_EXEC_FENCE_OUT;
 	execbuf.rsvd1 = ctx->id;
@@ -399,7 +406,7 @@ static void __capture1(int fd, int dir, uint64_t ahnd, const intel_ctx_t *ctx,
 	gem_execbuf_wr(fd, &execbuf);
 
 	fence_out = execbuf.rsvd2 >> 32;
-	igt_assert(fence_out >= 0);
+	igt_assert_lte(0, fence_out);
 
 	/* Wait for the request to start */
 	while (READ_ONCE(*seqno) != 0xc0ffee)
@@ -579,7 +586,7 @@ __captureN(int fd, int dir, uint64_t ahnd, const intel_ctx_t *ctx,
 	execbuf.buffers_ptr = (uintptr_t)obj;
 	execbuf.buffer_count = count + 2;
 	execbuf.flags = e->flags;
-	if (gen > 3 && gen < 6)
+	if (gem_store_dword_needs_secure(fd))
 		execbuf.flags |= I915_EXEC_SECURE;
 	execbuf.flags |= I915_EXEC_FENCE_OUT;
 	execbuf.rsvd1 = ctx->id;
@@ -656,13 +663,18 @@ static bool needs_recoverable_ctx(int fd)
 
 #define find_first_available_engine(fd, ctx, e, saved) \
 	do { \
+		struct intel_execution_engine2 *tmpe = NULL; \
+		e = NULL; \
+		\
 		ctx = intel_ctx_create_all_physical(fd); \
 		igt_assert(ctx); \
-		for_each_ctx_engine(fd, ctx, e) \
-			for_each_if(gem_class_can_store_dword(fd, e->class)) \
+		for_each_ctx_engine(fd, ctx, tmpe) \
+			if(gem_class_can_store_dword(fd, tmpe->class)) { \
+				saved = configure_hangs(fd, tmpe, ctx->id); \
+				e = &saved.engine; \
 				break; \
-		igt_assert(e); \
-		saved = configure_hangs(fd, e, ctx->id); \
+			} \
+		igt_skip_on_f(e == NULL, "no capable engine found\n"); \
 	} while(0)
 
 static void many(int fd, int dir, uint64_t size, unsigned int flags)
@@ -780,11 +792,11 @@ static void prioinv(int fd, int dir, const intel_ctx_t *ctx,
 				&fence_out, REGION_SMEM, true));
 		put_ahnd(ahnd);
 
-		write(link[1], &fd, sizeof(fd)); /* wake the parent up */
+		igt_assert_eq(write(link[1], &fd, sizeof(fd)), sizeof(fd)); /* wake the parent up */
 		wait_to_die(fence_out);
-		write(link[1], &fd, sizeof(fd)); /* wake the parent up */
+		igt_assert_eq(write(link[1], &fd, sizeof(fd)), sizeof(fd)); /* wake the parent up */
 	}
-	read(link[0], &dummy, sizeof(dummy));
+	igt_assert_eq(read(link[0], &dummy, sizeof(dummy)), sizeof(dummy));
 	igt_require_f(poll(&(struct pollfd){link[0], POLLIN}, 1, 500) == 0,
 		      "Capture completed too quickly! Will not block\n");
 
@@ -956,12 +968,9 @@ igt_main
 	uint32_t region;
 
 	igt_fixture {
-		int gen;
-
 		fd = drm_open_driver(DRIVER_INTEL);
 
-		gen = intel_gen(intel_get_drm_devid(fd));
-		if (gen > 3 && gen < 6) /* ctg and ilk need secure batches */
+		if (gem_store_dword_needs_secure(fd))
 			igt_device_set_master(fd);
 
 		igt_require_gem(fd);
@@ -977,7 +986,7 @@ igt_main
 
 			gem_context_set_param(fd, &param);
 		}
-		igt_allow_hang(fd, ctx->id, HANG_ALLOW_CAPTURE | HANG_WANT_ENGINE_RESET);
+		hang = igt_allow_hang(fd, ctx->id, HANG_ALLOW_CAPTURE | HANG_WANT_ENGINE_RESET);
 
 		dir = igt_sysfs_open(fd);
 		igt_require(igt_sysfs_set(dir, "error", "Begone!"));
