@@ -29,9 +29,7 @@
  * Category: Display
  * Description: Test cdclk features : crawling and squashing
  * Driver requirement: i915, xe
- * Functionality: kms_core
  * Mega feature: General Display Features
- * Test category: functionality test
  */
 
 #include "igt.h"
@@ -53,7 +51,6 @@ IGT_TEST_DESCRIPTION("Test cdclk features : crawling and squashing");
 #define HDISPLAY_4K	3840
 #define VDISPLAY_4K	2160
 #define VREFRESH	60
-#define MAX_CDCLK_4K	307200
 
 /* Test flags */
 enum {
@@ -63,7 +60,6 @@ enum {
 
 typedef struct {
 	int drm_fd;
-	int debugfs_fd;
 	uint32_t devid;
 	igt_display_t display;
 } data_t;
@@ -76,56 +72,23 @@ static bool hardware_supported(data_t *data)
 	return false;
 }
 
-static int get_current_cdclk_freq(int debugfs_fd)
-{
-	int cdclk_freq_current;
-	char buf[1024];
-	char *start_loc;
-	int res;
-
-	/*
-	 * Display specific clock frequency info is moved to i915_cdclk_info,
-	 * On older kernels if this debugfs is not found, fallback to read from
-	 * i915_frequency_info.
-	 *
-	 * FIXME: As of now, XE debugfs is still using i915 namespace, once the
-	 * Kernel changes are landed, update this to use the XE specific debugfs.
-	 */
-	res = igt_debugfs_simple_read(debugfs_fd, "i915_cdclk_info",
-				      buf, sizeof(buf));
-	if (res <= 0)
-		res = igt_debugfs_simple_read(debugfs_fd, "i915_frequency_info",
-					      buf, sizeof(buf));
-	igt_require(res > 0);
-
-	igt_assert(start_loc = strstr(buf, "Current CD clock frequency: "));
-	igt_assert_eq(sscanf(start_loc, "Current CD clock frequency: %d", &cdclk_freq_current), 1);
-
-	return cdclk_freq_current;
-}
-
 static __u64 get_mode_data_rate(drmModeModeInfo *mode)
 {
 	__u64 data_rate = (__u64)mode->hdisplay * (__u64)mode->vdisplay * (__u64)mode->vrefresh;
 	return data_rate;
 }
 
-static drmModeModeInfo *get_highres_mode(igt_output_t *output)
+static bool is_4k(drmModeModeInfo mode)
 {
-	drmModeModeInfo *highest_mode = NULL;
-	drmModeConnector *connector = output->config.connector;
-	int j;
+	return (mode.hdisplay >= HDISPLAY_4K && mode.vdisplay >= VDISPLAY_4K &&
+	        mode.vrefresh >= VREFRESH);
+}
 
-	for (j = 0; j < connector->count_modes; j++) {
-		if (connector->modes[j].vdisplay == VDISPLAY_4K &&
-		    connector->modes[j].hdisplay == HDISPLAY_4K &&
-		    connector->modes[j].vrefresh == VREFRESH) {
-			highest_mode = &connector->modes[j];
-			break;
-		}
-	}
-
-	return highest_mode;
+static bool is_equal(drmModeModeInfo mode_hi, drmModeModeInfo mode_lo)
+{
+	return (mode_hi.hdisplay == mode_lo.hdisplay &&
+		mode_hi.vdisplay == mode_lo.vdisplay &&
+		mode_hi.vrefresh == mode_lo.vrefresh);
 }
 
 static drmModeModeInfo *get_lowres_mode(igt_output_t *output)
@@ -168,11 +131,10 @@ static void do_cleanup_display(igt_display_t *dpy)
 static void test_plane_scaling(data_t *data, enum pipe pipe, igt_output_t *output)
 {
 	igt_display_t *display = &data->display;
-	int debugfs_fd = data->debugfs_fd;
 	int cdclk_ref, cdclk_new;
 	struct igt_fb fb;
 	igt_plane_t *primary;
-	drmModeModeInfo *mode;
+	drmModeModeInfo mode;
 	int scaling = 50;
 	int ret;
 	bool test_complete = false;
@@ -182,14 +144,16 @@ static void test_plane_scaling(data_t *data, enum pipe pipe, igt_output_t *outpu
 		igt_display_reset(display);
 
 		igt_output_set_pipe(output, pipe);
-		mode = get_highres_mode(output);
-		igt_require(mode != NULL);
-		igt_output_override_mode(output, mode);
+		mode = *igt_output_get_highres_mode(output);
+		igt_require_f(is_4k(mode), "Mode >= 4K not found on output %s\n",
+			      igt_output_name(output));
+
+		igt_output_override_mode(output, &mode);
 
 		primary = igt_output_get_plane_type(output, DRM_PLANE_TYPE_PRIMARY);
 
 		igt_create_color_pattern_fb(display->drm_fd,
-					    mode->hdisplay, mode->vdisplay,
+					    mode.hdisplay, mode.vdisplay,
 					    DRM_FORMAT_XRGB8888,
 					    DRM_FORMAT_MOD_LINEAR,
 					    0.0, 0.0, 0.0, &fb);
@@ -197,11 +161,11 @@ static void test_plane_scaling(data_t *data, enum pipe pipe, igt_output_t *outpu
 
 		/* downscaling */
 		igt_plane_set_size(primary, ((fb.width * scaling) / 100), ((fb.height * scaling) / 100));
-		cdclk_ref = get_current_cdclk_freq(debugfs_fd);
+		cdclk_ref = igt_get_current_cdclk(data->drm_fd);
 		ret = igt_display_try_commit_atomic(display, DRM_MODE_ATOMIC_ALLOW_MODESET, NULL);
 		if (ret != -EINVAL) {
 			igt_display_commit_atomic(display, DRM_MODE_ATOMIC_ALLOW_MODESET, NULL);
-			cdclk_new = get_current_cdclk_freq(debugfs_fd);
+			cdclk_new = igt_get_current_cdclk(data->drm_fd);
 			igt_info("CD clock frequency %d -> %d\n", cdclk_ref, cdclk_new);
 
 			/* cdclk should bump */
@@ -221,23 +185,22 @@ static void test_plane_scaling(data_t *data, enum pipe pipe, igt_output_t *outpu
 static void test_mode_transition(data_t *data, enum pipe pipe, igt_output_t *output)
 {
 	igt_display_t *display = &data->display;
-	int debugfs_fd = data->debugfs_fd;
 	int cdclk_ref, cdclk_new;
 	struct igt_fb fb;
 	igt_plane_t *primary;
-	drmModeModeInfo *mode_hi, *mode_lo, *mode;
+	drmModeModeInfo mode_hi, mode_lo, *mode;
 
 	do_cleanup_display(display);
 	igt_display_reset(display);
 
 	igt_output_set_pipe(output, pipe);
 	mode = igt_output_get_mode(output);
-	mode_lo = get_lowres_mode(output);
-	mode_hi = get_highres_mode(output);
-	igt_require(mode_hi != NULL);
+	mode_lo = *get_lowres_mode(output);
+	mode_hi = *igt_output_get_highres_mode(output);
+	igt_require_f(is_4k(mode_hi), "Mode >= 4K not found on output %s\n",
+	              igt_output_name(output));
 
-	igt_skip_on_f(mode_hi->hdisplay == mode_lo->hdisplay && mode_hi->vdisplay == mode_lo->vdisplay,
-		      "Highest and lowest mode resolutions are same; no transition\n");
+	igt_skip_on_f(is_equal(mode_hi, mode_lo), "Highest and lowest mode resolutions are same; no transition\n");
 
 	primary = igt_output_get_plane_type(output, DRM_PLANE_TYPE_PRIMARY);
 
@@ -248,20 +211,20 @@ static void test_mode_transition(data_t *data, enum pipe pipe, igt_output_t *out
 				    0.0, 0.0, 0.0, &fb);
 
 	/* switch to lower resolution */
-	igt_output_override_mode(output, mode_lo);
+	igt_output_override_mode(output, &mode_lo);
 	igt_plane_set_fb(primary, &fb);
 	igt_display_commit_atomic(display, DRM_MODE_ATOMIC_ALLOW_MODESET, NULL);
-	cdclk_ref = get_current_cdclk_freq(debugfs_fd);
+	cdclk_ref = igt_get_current_cdclk(data->drm_fd);
 
 	/* switch to higher resolution */
-	igt_output_override_mode(output, mode_hi);
+	igt_output_override_mode(output, &mode_hi);
 	igt_plane_set_fb(primary, &fb);
 	igt_display_commit_atomic(display, DRM_MODE_ATOMIC_ALLOW_MODESET, NULL);
-	cdclk_new = get_current_cdclk_freq(debugfs_fd);
+	cdclk_new = igt_get_current_cdclk(data->drm_fd);
 	igt_info("CD clock frequency %d -> %d\n", cdclk_ref, cdclk_new);
 
 	/* cdclk should bump */
-	if (cdclk_new != MAX_CDCLK_4K)
+	if (cdclk_new != igt_get_max_cdclk(data->drm_fd))
 		igt_assert_lt(cdclk_ref, cdclk_new);
 
 	/* cleanup */
@@ -269,98 +232,88 @@ static void test_mode_transition(data_t *data, enum pipe pipe, igt_output_t *out
 	igt_remove_fb(display->drm_fd, &fb);
 }
 
+static void set_mode(data_t *data, int count, drmModeModeInfo *mode,
+		     igt_output_t **valid_outputs, struct igt_fb fb)
+{
+	igt_display_t *display = &data->display;
+	igt_pipe_t *pipe;
+	igt_plane_t *plane;
+
+	for (int i = 0; i < count; i++) {
+		pipe = &display->pipes[i];
+		plane = igt_pipe_get_plane_type(pipe, DRM_PLANE_TYPE_PRIMARY);
+
+		igt_output_override_mode(valid_outputs[i], &mode[i]);
+
+		igt_plane_set_fb(plane, &fb);
+		igt_fb_set_size(&fb, plane, mode[i].hdisplay, mode[i].vdisplay);
+		igt_plane_set_size(plane, mode[i].hdisplay, mode[i].vdisplay);
+	}
+}
+
 static void test_mode_transition_on_all_outputs(data_t *data)
 {
 	igt_display_t *display = &data->display;
-	int debugfs_fd = data->debugfs_fd;
-	drmModeModeInfo *mode, *mode_hi, *mode_lo;
+	drmModeModeInfo *mode, mode_highres[IGT_MAX_PIPES] = {0}, mode_lowres[IGT_MAX_PIPES] = {0};
+	igt_output_t *valid_outputs[IGT_MAX_PIPES] = {NULL};
 	igt_output_t *output;
-	int valid_outputs = 0;
+	int count = 0;
 	int cdclk_ref, cdclk_new;
 	uint16_t width = 0, height = 0;
 	struct igt_fb fb;
-	igt_pipe_t *pipe;
-	igt_plane_t *plane;
-	int i = 0, j = 0;
 
 	do_cleanup_display(display);
 	igt_display_reset(display);
 
-	for_each_connected_output(&data->display, output)
-		valid_outputs++;
-
-	i = 0;
 	for_each_connected_output(display, output) {
-		mode = igt_output_get_mode(output);
+		mode_highres[count] = *igt_output_get_highres_mode(output);
+		igt_require_f(is_4k(mode_highres[count]), "Mode >= 4K not found on output %s.\n",
+			      igt_output_name(output));
+
+		mode_lowres[count] = *get_lowres_mode(output);
+
+		if (is_equal(mode_highres[count], mode_lowres[count])) {
+			igt_info("Highest and lowest mode resolutions are same on output %s; no transition will occur, skipping\n",
+				  igt_output_name(output));
+			continue;
+		}
+
+		valid_outputs[count] = output;
+		count++;
+	}
+
+	igt_skip_on_f(count < 2,
+		      "Number of valid outputs (%d) must be greater than or equal to 2\n", count);
+
+	for (int i = 0; i < count; i++) {
+		mode = igt_output_get_mode(valid_outputs[i]);
 		igt_assert(mode);
 
 		width = max(width, mode->hdisplay);
 		height = max(height, mode->vdisplay);
 
-		mode_hi = get_highres_mode(output);
-		igt_require(mode_hi != NULL);
-
-		igt_output_set_pipe(output, i);
-		igt_output_override_mode(output, mode_hi);
-		i++;
+		igt_output_set_pipe(valid_outputs[i], i);
+		igt_output_override_mode(valid_outputs[i], &mode_highres[i]);
 	}
+
 	igt_require(intel_pipe_output_combo_valid(display));
-	igt_display_reset(display);
 
 	igt_create_pattern_fb(data->drm_fd, width, height, DRM_FORMAT_XRGB8888,
 			      DRM_FORMAT_MOD_LINEAR, &fb);
-	i = 0;
-	for_each_connected_output(display, output) {
-		pipe = &display->pipes[i];
-		plane = igt_pipe_get_plane_type(pipe, DRM_PLANE_TYPE_PRIMARY);
-
-		mode = NULL;
-
-		igt_output_set_pipe(output, i);
-		mode = igt_output_get_mode(output);
-		igt_assert(mode);
-
-		mode_lo = get_lowres_mode(output);
-
-		igt_output_override_mode(output, mode_lo);
-		igt_plane_set_fb(plane, &fb);
-		igt_fb_set_size(&fb, plane, mode_lo->hdisplay, mode_lo->vdisplay);
-		igt_plane_set_size(plane, mode_lo->hdisplay, mode_lo->vdisplay);
-		i++;
-	}
 
+	set_mode(data, count, mode_lowres, valid_outputs, fb);
 	igt_display_commit2(display, COMMIT_ATOMIC);
-	cdclk_ref = get_current_cdclk_freq(debugfs_fd);
-
-	j = 0;
-	for_each_connected_output(display, output) {
-		pipe = &display->pipes[j];
-		plane = igt_pipe_get_plane_type(pipe, DRM_PLANE_TYPE_PRIMARY);
-
-		mode = NULL;
-
-		igt_output_set_pipe(output, j);
-		mode = igt_output_get_mode(output);
-		igt_assert(mode);
-
-		mode_hi = get_highres_mode(output);
-		igt_require(mode_hi != NULL);
-
-		igt_output_override_mode(output, mode_hi);
-		igt_plane_set_fb(plane, &fb);
-		igt_fb_set_size(&fb, plane, mode_hi->hdisplay, mode_hi->vdisplay);
-		igt_plane_set_size(plane, mode_hi->hdisplay, mode_hi->vdisplay);
-		j++;
-	}
+	cdclk_ref = igt_get_current_cdclk(data->drm_fd);
 
+	set_mode(data, count, mode_highres, valid_outputs, fb);
 	igt_display_commit2(display, COMMIT_ATOMIC);
-	cdclk_new = get_current_cdclk_freq(debugfs_fd);
+	cdclk_new = igt_get_current_cdclk(data->drm_fd);
 	igt_info("CD clock frequency %d -> %d\n", cdclk_ref, cdclk_new);
 
 	/* cdclk should bump */
-	igt_assert_lt(cdclk_ref, cdclk_new);
+	if (cdclk_new != igt_get_max_cdclk(data->drm_fd))
+		igt_assert_lt(cdclk_ref, cdclk_new);
 
-	igt_plane_set_fb(plane, NULL);
 	do_cleanup_display(display);
 	igt_remove_fb(data->drm_fd, &fb);
 }
@@ -394,8 +347,6 @@ igt_main
 	igt_fixture {
 		data.drm_fd = drm_open_driver_master(DRIVER_INTEL | DRIVER_XE);
 		igt_require(data.drm_fd >= 0);
-		data.debugfs_fd = igt_debugfs_dir(data.drm_fd);
-		igt_require(data.debugfs_fd);
 		kmstest_set_vt_graphics_mode();
 		data.devid = intel_get_drm_devid(data.drm_fd);
 		igt_require_f(hardware_supported(&data),
