@@ -7,12 +7,13 @@
  * TEST: Tests for eudebug online functionality
  * Category: Core
  * Mega feature: EUdebug
- * Sub-category: EUdebug tests
+ * Sub-category: EUdebug online
  * Functionality: eu kernel debug
  * Test category: functionality test
  */
 
 #include "xe/xe_eudebug.h"
+#include "xe/xe_gt.h"
 #include "xe/xe_ioctl.h"
 #include "xe/xe_query.h"
 #include "igt.h"
@@ -38,6 +39,7 @@
 #define TARGET_IN_VRAM			(1 << 13)
 #define SHADER_PAGEFAULT_READ		(1 << 14)
 #define SHADER_PAGEFAULT_WRITE		(1 << 15)
+#define FAULTABLE_VM			(1 << 16)
 #define TRIGGER_UFENCE_SET_BREAKPOINT	(1 << 24)
 #define TRIGGER_RESUME_SINGLE_WALK	(1 << 25)
 #define TRIGGER_RESUME_PARALLEL_WALK	(1 << 26)
@@ -1020,12 +1022,11 @@ static struct intel_bb *xe_bb_create_on_offset(int fd, uint32_t exec_queue, uint
 	return ibb;
 }
 
-static size_t get_bb_size(int flags)
+static size_t get_bb_size(int fd, struct gpgpu_shader *shader)
 {
-	if ((flags & SHADER_CACHING_SRAM) || (flags & SHADER_CACHING_VRAM))
-		return 32768;
+	size_t shader_size = shader->size * sizeof(uint32_t);
 
-	return 4096;
+	return ALIGN(shader_size, PAGE_SIZE) + xe_cs_prefetch_size(fd);
 }
 
 static uint64_t get_memory_region(int fd, int flags, int region_bitmask)
@@ -1044,7 +1045,7 @@ static void run_online_client(struct xe_eudebug_client *c)
 	int threads = get_number_of_threads(c->flags);
 	const uint64_t target_offset = 0x1a000000;
 	const uint64_t bb_offset = 0x1b000000;
-	const size_t bb_size = get_bb_size(c->flags);
+	size_t bb_size;
 	struct online_debug_data *data = c->ptr;
 	struct drm_xe_engine_class_instance hwe = data->hwe;
 	struct drm_xe_ext_set_property ext = {
@@ -1076,6 +1077,9 @@ static void run_online_client(struct xe_eudebug_client *c)
 
 	fd = xe_eudebug_client_open_driver(c);
 
+	shader = get_shader(fd, c->flags);
+	bb_size = get_bb_size(fd, shader);
+
 	/* Additional memory for steering control */
 	if (c->flags & SHADER_LOOP || c->flags & SHADER_SINGLE_STEP || c->flags & SHADER_PAGEFAULT)
 		s_dim.y++;
@@ -1098,7 +1102,8 @@ static void run_online_client(struct xe_eudebug_client *c)
 							   2 * sizeof(**metadata), metadata[1]);
 
 	vm_flags = DRM_XE_VM_CREATE_FLAG_LR_MODE;
-	vm_flags |= c->flags & SHADER_PAGEFAULT ? DRM_XE_VM_CREATE_FLAG_FAULT_MODE : 0;
+	vm_flags |= c->flags & (SHADER_PAGEFAULT | FAULTABLE_VM) ?
+			DRM_XE_VM_CREATE_FLAG_FAULT_MODE : 0;
 
 	create.vm_id = xe_eudebug_client_vm_create(c, fd, vm_flags, 0);
 
@@ -1109,7 +1114,6 @@ static void run_online_client(struct xe_eudebug_client *c)
 	intel_bb_set_lr_mode(ibb, true);
 
 	sip = get_sip(fd, c->flags);
-	shader = get_shader(fd, c->flags);
 
 	igt_nsec_elapsed(&ts);
 	gpgpu_shader_exec(ibb, buf, w_dim.x, w_dim.y, shader, sip, 0, 0);
@@ -1430,23 +1434,27 @@ static void pagefault_trigger(struct xe_eudebug_debugger *d,
 
 /**
  * SUBTEST: basic-breakpoint
+ * Functionality: EU attention event
  * Description:
  *	Check whether KMD sends attention events
  *	for workload in debug mode stopped on breakpoint.
  *
  * SUBTEST: breakpoint-not-in-debug-mode
+ * Functionality: EU attention event
  * Description:
  *	Check whether KMD resets the GPU when it spots an attention
  *	coming from workload not in debug mode.
  *
  * SUBTEST: stopped-thread
+ * Functionality: EU attention event
  * Description:
  *	Hits breakpoint on runalone workload and
  *	reads attention for fixed time.
  *
  * SUBTEST: resume-%s
+ * Functionality: EU control
  * Description:
- *	Resumes stopped on a breakpoint workload
+ *	Workload stopped on a breakpoint is resumed
  *	with granularity of %arg[1].
  *
  *
@@ -1479,8 +1487,14 @@ static void test_basic_online(int fd, struct drm_xe_engine_class_instance *hwe,
 
 /**
  * SUBTEST: set-breakpoint
+ * Functionality: dynamic breakpoint
  * Description:
  *	Checks for attention after setting a dynamic breakpoint in the ufence event.
+ *
+ * SUBTEST: set-breakpoint-faultable
+ * Functionality: dynamic breakpoint with FAULTABLE_VM
+ * Description:
+ *	Faultable variation of test set-breakpoint.
  */
 
 static void test_set_breakpoint_online(int fd, struct drm_xe_engine_class_instance *hwe, int flags)
@@ -1488,6 +1502,8 @@ static void test_set_breakpoint_online(int fd, struct drm_xe_engine_class_instan
 	struct xe_eudebug_session *s;
 	struct online_debug_data *data;
 
+	igt_require(!(flags & FAULTABLE_VM) || !xe_supports_faults(fd));
+
 	data = online_debug_data_create(hwe);
 	s = xe_eudebug_session_create(fd, run_online_client, flags, data);
 	xe_eudebug_debugger_add_trigger(s->debugger, DRM_XE_EUDEBUG_EVENT_OPEN,
@@ -1511,6 +1527,7 @@ static void test_set_breakpoint_online(int fd, struct drm_xe_engine_class_instan
 
 /**
  * SUBTEST: set-breakpoint-sigint-debugger
+ * Functionality: SIGINT
  * Description:
  *	A variant of set-breakpoint that sends SIGINT to the debugger thread with random timing
  *	and checks if nothing breaks, exercising the scenario multiple times.
@@ -1603,11 +1620,13 @@ static void test_set_breakpoint_online_sigint_debugger(int fd,
 
 /**
  * SUBTEST: pagefault-read
+ * Functionality: page faults
  * Description:
  *     Check whether KMD sends pagefault event for workload in debug mode that
  *     triggers a read pagefault.
  *
  * SUBTEST: pagefault-write
+ * Functionality: page faults
  * Description:
  *     Check whether KMD sends pagefault event for workload in debug mode that
  *     triggers a write pagefault.
@@ -1646,6 +1665,7 @@ static void test_pagefault_online(int fd, struct drm_xe_engine_class_instance *h
 
 /**
  * SUBTEST: preempt-breakpoint
+ * Functionality: EUdebug preemption timeout
  * Description:
  *	Verify that eu debugger disables preemption timeout to
  *	prevent reset of workload stopped on breakpoint.
@@ -1691,6 +1711,7 @@ static void test_preemption(int fd, struct drm_xe_engine_class_instance *hwe)
 
 /**
  * SUBTEST: reset-with-attention
+ * Functionality: EUdebug preemption timeout
  * Description:
  *	Check whether GPU is usable after resetting with attention raised
  *	(stopped on breakpoint) by running the same workload again.
@@ -1728,17 +1749,24 @@ static void test_reset_with_attention_online(int fd, struct drm_xe_engine_class_
 
 /**
  * SUBTEST: interrupt-all
+ * Functionality: EU control
  * Description:
  *	Schedules EU workload which should last about a few seconds, then
  *	interrupts all threads, checks whether attention event came, and
  *	resumes stopped threads back.
  *
  * SUBTEST: interrupt-all-set-breakpoint
+ * Functionality: dynamic breakpoint
  * Description:
  *	Schedules EU workload which should last about a few seconds, then
  *	interrupts all threads, once attention event come it sets breakpoint on
  *	the very next instruction and resumes stopped threads back. It expects
  *	that every thread hits the breakpoint.
+ *
+ * SUBTEST: interrupt-all-set-breakpoint-faultable
+ * Functionality: dynamic breakpoint with FAULTABLE_VM
+ * Description:
+ *	Faultable variation of test interrupt-all-set-breakpoint.
  */
 static void test_interrupt_all(int fd, struct drm_xe_engine_class_instance *hwe, int flags)
 {
@@ -1746,6 +1774,8 @@ static void test_interrupt_all(int fd, struct drm_xe_engine_class_instance *hwe,
 	struct online_debug_data *data;
 	uint32_t val;
 
+	igt_require(!(flags & FAULTABLE_VM) || !xe_supports_faults(fd));
+
 	data = online_debug_data_create(hwe);
 	s = xe_eudebug_session_create(fd, run_online_client, flags, data);
 
@@ -1815,12 +1845,14 @@ static void reset_debugger_log(struct xe_eudebug_debugger *d)
 
 /**
  * SUBTEST: interrupt-other-debuggable
+ * Functionality: EU control
  * Description:
  *	Schedules EU workload in runalone mode with never ending loop, while
  *	it is not under debug, tries to interrupt all threads using the different
  *	client attached to debugger.
  *
  * SUBTEST: interrupt-other
+ * Functionality: EU control
  * Description:
  *	Schedules EU workload with a never ending loop and, while it is not
  *	configured for debugging, tries to interrupt all threads using the client
@@ -1909,6 +1941,7 @@ static void test_interrupt_other(int fd, struct drm_xe_engine_class_instance *hw
 
 /**
  * SUBTEST: tdctl-parameters
+ * Functionality: EU control
  * Description:
  *	Schedules EU workload which should last about a few seconds, then
  *	checks negative scenarios of EU_THREADS ioctl usage, interrupts all threads,
@@ -2061,6 +2094,7 @@ static void eu_attention_debugger_detach_trigger(struct xe_eudebug_debugger *d,
 
 /**
  * SUBTEST: interrupt-reconnect
+ * Functionality: reopen connection
  * Description:
  *	Schedules EU workload which should last about a few seconds,
  *	interrupts all threads and detaches debugger when attention is
@@ -2134,12 +2168,14 @@ static void test_interrupt_reconnect(int fd, struct drm_xe_engine_class_instance
 
 /**
  * SUBTEST: single-step
+ * Functionality: EU control
  * Description:
  *	Schedules EU workload with 16 nops after breakpoint, then single-steps
  *	through the shader, advances all threads each step, checking if all
  *	threads advanced every step.
  *
  * SUBTEST: single-step-one
+ * Functionality: EU control
  * Description:
  *	Schedules EU workload with 16 nops after breakpoint, then single-steps
  *	through the shader, advances one thread each step, checking if one
@@ -2191,6 +2227,7 @@ static void eu_attention_debugger_ndetach_trigger(struct xe_eudebug_debugger *d,
 
 /**
  * SUBTEST: debugger-reopen
+ * Functionality: reopen connection
  * Description:
  *	Check whether the debugger is able to reopen the connection and
  *	capture the events of already running client.
@@ -2221,6 +2258,7 @@ static void test_debugger_reopen(int fd, struct drm_xe_engine_class_instance *hw
 
 /**
  * SUBTEST: writes-caching-%s-bb-%s-target-%s
+ * Functionality: cache coherency
  * Description:
  *	Write incrementing values to 2-page-long target surface, poisoning the data one breakpoint
  *	before each write instruction and restoring it when the poisoned instruction breakpoint
@@ -2346,12 +2384,14 @@ static uint64_t timespecs_diff_us(struct timespec *ts1, struct timespec *ts2)
 
 /**
  * SUBTEST: breakpoint-many-sessions-single-tile
+ * Functionality: multisession
  * Description:
  *	Schedules EU workload with preinstalled breakpoint on every compute engine
  *	available on the tile. Checks if the contexts hit breakpoint in sequence
  *	and resumes them.
  *
  * SUBTEST: breakpoint-many-sessions-tiles
+ * Functionality: multisession multiTile
  * Description:
  *	Schedules EU workload with preinstalled breakpoint on selected compute
  *      engines, with one per tile. Checks if each context hit breakpoint and
@@ -2521,6 +2561,10 @@ igt_main
 	test_gt_render_or_compute("set-breakpoint", fd, hwe)
 		test_set_breakpoint_online(fd, hwe, SHADER_NOP | TRIGGER_UFENCE_SET_BREAKPOINT);
 
+	test_gt_render_or_compute("set-breakpoint-faultable", fd, hwe)
+		test_set_breakpoint_online(fd, hwe,
+					   SHADER_NOP | TRIGGER_UFENCE_SET_BREAKPOINT | FAULTABLE_VM);
+
 	test_gt_render_or_compute("set-breakpoint-sigint-debugger", fd, hwe)
 		test_set_breakpoint_online_sigint_debugger(fd, hwe,
 							   SHADER_NOP | TRIGGER_UFENCE_SET_BREAKPOINT);
@@ -2563,6 +2607,9 @@ igt_main
 	test_gt_render_or_compute("interrupt-all-set-breakpoint", fd, hwe)
 		test_interrupt_all(fd, hwe, SHADER_LOOP | TRIGGER_RESUME_SET_BP);
 
+	test_gt_render_or_compute("interrupt-all-set-breakpoint-faultable", fd, hwe)
+		test_interrupt_all(fd, hwe, SHADER_LOOP | TRIGGER_RESUME_SET_BP | FAULTABLE_VM);
+
 	test_gt_render_or_compute("tdctl-parameters", fd, hwe)
 		test_tdctl_parameters(fd, hwe, SHADER_LOOP);
 
