@@ -93,6 +93,8 @@ static void run_extendedmode_basic(data_t *data,
 	mode[0] = igt_output_get_mode(output1);
 	mode[1] = igt_output_get_mode(output2);
 
+	igt_assert_f(igt_fit_modes_in_bw(display), "Unable to fit modes in bw\n");
+
 	pipe_crc[0] = igt_pipe_crc_new(data->drm_fd, pipe1, IGT_PIPE_CRC_SOURCE_AUTO);
 	pipe_crc[1] = igt_pipe_crc_new(data->drm_fd, pipe2, IGT_PIPE_CRC_SOURCE_AUTO);
 
@@ -138,6 +140,7 @@ static void run_extendedmode_basic(data_t *data,
 	igt_fb_set_size(&fb, plane[1], mode[1]->hdisplay, mode[1]->vdisplay);
 	igt_plane_set_size(plane[1], mode[1]->hdisplay, mode[1]->vdisplay);
 
+	igt_assert_f(igt_fit_modes_in_bw(display), "Unable to fit modes in bw\n");
 	igt_display_commit2(display, COMMIT_ATOMIC);
 
 	igt_pipe_crc_collect_crc(pipe_crc[0], &crc[0]);
@@ -158,6 +161,7 @@ static void run_extendedmode_basic(data_t *data,
 			  DRM_PLANE_TYPE_PRIMARY), NULL);
 	igt_plane_set_fb(igt_pipe_get_plane_type(&display->pipes[pipe2],
 			  DRM_PLANE_TYPE_PRIMARY), NULL);
+	igt_assert_f(igt_fit_modes_in_bw(display), "Unable to fit modes in bw\n");
 	igt_display_commit2(display, COMMIT_ATOMIC);
 
 	/*Compare CRC*/
@@ -184,11 +188,6 @@ static void run_extendedmode_test(data_t *data) {
 	for_each_pipe(display, pipe1) {
 		for_each_valid_output_on_pipe(display, pipe1, output1) {
 
-			if (is_joiner_mode(data->drm_fd, output1)) {
-				igt_info("Skipping joiner output %s", output1->name);
-				continue;
-			}
-
 			for_each_pipe(display, pipe2) {
 				if (pipe1 == pipe2)
 					continue;
@@ -238,10 +237,6 @@ igt_main
 		igt_display_require_output(&data.display);
 
 		for_each_connected_output(&data.display, output) {
-			if (is_joiner_mode(data.drm_fd, output)) {
-				igt_info("Skipping joiner output %s", output->name);
-				continue;
-			}
 			data.mst_output[count++] = output;
 			if (output_is_dp_mst(&data, output, dp_mst_outputs))
 				dp_mst_outputs++;
