@@ -49,7 +49,7 @@ igt_main
 	}
 
 	igt_subtest("get-bad-flags") {
-		int bo = igt_vc4_create_bo(fd, PAGE_SIZE);
+		int bo = igt_vc4_create_bo(fd, VC4_GPU_PAGE_SIZE);
 		struct drm_vc4_get_tiling get = {
 			.handle = bo,
 			.flags = 0xd0d0d0d0,
@@ -59,7 +59,7 @@ igt_main
 	}
 
 	igt_subtest("set-bad-flags") {
-		int bo = igt_vc4_create_bo(fd, PAGE_SIZE);
+		int bo = igt_vc4_create_bo(fd, VC4_GPU_PAGE_SIZE);
 		struct drm_vc4_set_tiling set = {
 			.handle = bo,
 			.flags = 0xd0d0d0d0,
@@ -70,7 +70,7 @@ igt_main
 	}
 
 	igt_subtest("get-bad-modifier") {
-		int bo = igt_vc4_create_bo(fd, PAGE_SIZE);
+		int bo = igt_vc4_create_bo(fd, VC4_GPU_PAGE_SIZE);
 		struct drm_vc4_get_tiling get = {
 			.handle = bo,
 			.modifier = 0xd0d0d0d0,
@@ -80,7 +80,7 @@ igt_main
 	}
 
 	igt_subtest("set-bad-modifier") {
-		int bo = igt_vc4_create_bo(fd, PAGE_SIZE);
+		int bo = igt_vc4_create_bo(fd, VC4_GPU_PAGE_SIZE);
 		struct drm_vc4_set_tiling set = {
 			.handle = bo,
 			.modifier = 0xd0d0d0d0,
@@ -90,7 +90,7 @@ igt_main
 	}
 
 	igt_subtest("set-get") {
-		int bo = igt_vc4_create_bo(fd, PAGE_SIZE);
+		int bo = igt_vc4_create_bo(fd, VC4_GPU_PAGE_SIZE);
 
 		/* Default is untiled. */
 		igt_assert(igt_vc4_get_tiling(fd, bo) == DRM_FORMAT_MOD_LINEAR);
@@ -111,7 +111,7 @@ igt_main
 		/* Some size that probably nobody else is using, to
 		 * encourage getting the same BO back from the cache.
 		 */
-		int size = 91 * PAGE_SIZE;
+		int size = 91 * VC4_GPU_PAGE_SIZE;
 		int bo;
 
 		bo = igt_vc4_create_bo(fd, size);
